Module: SomethingLikeThat

Defined in:
lib/something_like_that.rb,
lib/something_like_that/scorer.rb,
lib/something_like_that/version.rb,
lib/something_like_that/two_d_array.rb,
lib/something_like_that/match_phrase.rb,
lib/something_like_that/match_phrase/query.rb

Overview

This module encapsulates the entire Something Like That gem, and contains a top-level wrapper method to provide a simplified public interface.

Defined Under Namespace

Classes: MatchPhrase, Query, Scorer, TwoDArray

Constant Summary collapse

VERSION =
'0.1.2'

Class Method Summary collapse

Class Method Details

.new(phrase) ⇒ Object



9
10
11
# File 'lib/something_like_that.rb', line 9

def self.new(phrase)
  Query.new(phrase)
end